==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/python/VenvOptions.java <==
package io.github.cdklabs.projen.python;

/**
 * (experimental) Options for venv.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.912Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.python.VenvOptions")
@software.amazon.jsii.Jsii.Proxy(VenvOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface VenvOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Name of directory to store the environment in.
     * <p>
     * Default: ".env"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getEnvdir() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link VenvOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link VenvOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<VenvOptions> {
        java.lang.String envdir;

        /**
         * Sets the value of {@link VenvOptions#getEnvdir}
         * @param envdir Name of directory to store the environment in.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder envdir(java.lang.String envdir) {
            this.envdir = envdir;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link VenvOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public VenvOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link VenvOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements VenvOptions {
        private final java.lang.String envdir;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.envdir = software.amazon.jsii.Kernel.get(this, "envdir", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.envdir = builder.envdir;
        }

        @Override
        public final java.lang.String getEnvdir() {
            return this.envdir;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getEnvdir() != null) {
                data.set("envdir", om.valueToTree(this.getEnvdir()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.python.VenvOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            VenvOptions.Jsii$Proxy that = (VenvOptions.Jsii$Proxy) o;

            return this.envdir != null ? this.envdir.equals(that.envdir) : that.envdir == null;
        }

        @Override
        public final int hashCode() {
            int result = this.envdir != null ? this.envdir.hashCode() : 0;
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/python/VenvOptions.java <==
package io.github.cdklabs.projen.python;

/**
 * (experimental) Options for venv.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.578Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.python.VenvOptions")
@software.amazon.jsii.Jsii.Proxy(VenvOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface VenvOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Name of directory to store the environment in.
     * <p>
     * Default: ".env"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getEnvdir() {
        return null;
    }

    /**
     * (experimental) Path to the python executable to use.
     * <p>
     * Default: "python"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getPythonExec() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link VenvOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link VenvOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<VenvOptions> {
        java.lang.String envdir;
        java.lang.String pythonExec;

        /**
         * Sets the value of {@link VenvOptions#getEnvdir}
         * @param envdir Name of directory to store the environment in.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder envdir(java.lang.String envdir) {
            this.envdir = envdir;
            return this;
        }

        /**
         * Sets the value of {@link VenvOptions#getPythonExec}
         * @param pythonExec Path to the python executable to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pythonExec(java.lang.String pythonExec) {
            this.pythonExec = pythonExec;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link VenvOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public VenvOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link VenvOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements VenvOptions {
        private final java.lang.String envdir;
        private final java.lang.String pythonExec;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.envdir = software.amazon.jsii.Kernel.get(this, "envdir", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.pythonExec = software.amazon.jsii.Kernel.get(this, "pythonExec", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.envdir = builder.envdir;
            this.pythonExec = builder.pythonExec;
        }

        @Override
        public final java.lang.String getEnvdir() {
            return this.envdir;
        }

        @Override
        public final java.lang.String getPythonExec() {
            return this.pythonExec;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getEnvdir() != null) {
                data.set("envdir", om.valueToTree(this.getEnvdir()));
            }
            if (this.getPythonExec() != null) {
                data.set("pythonExec", om.valueToTree(this.getPythonExec()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.python.VenvOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            VenvOptions.Jsii$Proxy that = (VenvOptions.Jsii$Proxy) o;

            if (this.envdir != null ? !this.envdir.equals(that.envdir) : that.envdir != null) return false;
            return this.pythonExec != null ? this.pythonExec.equals(that.pythonExec) : that.pythonExec == null;
        }

        @Override
        public final int hashCode() {
            int result = this.envdir != null ? this.envdir.hashCode() : 0;
            result = 31 * result + (this.pythonExec != null ? this.pythonExec.hashCode() : 0);
            return result;
        }
    }
}
